Contributing — Riskfolio-Lib 0.1 documentation

# Contributing

## How to contribute?

I would like to people help me to:

- Improve documentation.

- Improve performance of existing code.

- Add new optimization objectives functions, robust estimation techniques or new functionalities.

- Write more examples using jupyter notebooks.

- Help me to write tests using pytest.

- Recommend new journal papers, articles, blog posts related to convex portfolio optimization that you think will improve the features of Riskfoli-Lib.

## Do you have any questions?

If you have any questions related to Riskfolio-Lib, please raise an issue and I will tag it as a question.

If you have questions unrelated to Riskfolio-Lib or want advisory, contact me through my blog financioneroncios, my linkedin or write me an email to dany.cajas.n@uni.pe